Index: fetch_configs/mojo.py |
diff --git a/recipes/mojo.py b/fetch_configs/mojo.py |
similarity index 89% |
rename from recipes/mojo.py |
rename to fetch_configs/mojo.py |
index f7316ace9299b1066e1b315ba165fdf6fd372280..e34c8e2fe4a5791bc43b97328bc4dd1714f8e4b7 100644 |
--- a/recipes/mojo.py |
+++ b/fetch_configs/mojo.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Mojo(recipe_util.Recipe): |
- """Basic Recipe class for Mojo.""" |
+class Mojo(config_util.Config): |
+ """Basic Config class for Mojo.""" |
@staticmethod |
def fetch_spec(props): |